import React from "react";
import {
  Box,
  Text,
  Heading,
  Flex,
  Image,
  VStack,
  Grid,
  GridItem,
} from "@chakra-ui/react";
import { ConsumerDetails } from "../variables/interface";
import ImageWithFallback from "@/components/image/ImageWithFallback";
import moment from "moment";

const ConsumerView = ({ consumer }: { consumer: ConsumerDetails }) => {
  return (
    <Box p="5" borderWidth="1px" borderRadius="lg" shadow="md">
      <Heading as="h2" size="lg" mb="4">
        Consumer Details
      </Heading>
      <Grid templateColumns="repeat(2, 1fr)" gap={4}>
        <GridItem>
          <Text fontWeight="bold">Contact Person:</Text>
          <Text>{consumer.contact_person}</Text>
        </GridItem>
        <GridItem>
          <Text fontWeight="bold">Mobile No:</Text>
          <Text>{consumer.mobile_no}</Text>
        </GridItem>
        <GridItem>
          <Text fontWeight="bold">DC Request:</Text>
          <Text>{consumer.dc_request ? "Yes" : "No"}</Text>
        </GridItem>
        <GridItem>
          <Text fontWeight="bold">Meter/Unmeter:</Text>
          <Text>{consumer.meter_un_meter ? "Yes" : "No"}</Text>
        </GridItem>
        {consumer?.meter_un_meter == 1 && (
          <>
            <GridItem>
              <Text fontWeight="bold">Meter No:</Text>
              <Text>{consumer.meter_no}</Text>
            </GridItem>
            <GridItem>
              <Text fontWeight="bold">Meter Reading:</Text>
              <Text>{consumer.meter_reading}</Text>
            </GridItem>
          </>
        )}
        {consumer?.meter_un_meter == 0 && (
          <GridItem>
            <Text fontWeight="bold">Un Meter Reason:</Text>
            <Text>{consumer.un_meter_reason}</Text>
          </GridItem>
        )}

        <GridItem>
          <Text fontWeight="bold">Paid Amount:</Text>
          <Text>{consumer.paid_amount}</Text>
        </GridItem>

        <GridItem>
          <Text fontWeight="bold">Category:</Text>
          <Text>{consumer.category || "N/A"}</Text>
        </GridItem>
        <GridItem>
          <Text fontWeight="bold">Remarks:</Text>
          <Text>{consumer.remarks || "N/A"}</Text>
        </GridItem>
        <GridItem>
          <Text fontWeight="bold">Remarks:</Text>
          <Text>{consumer.additional_remarks || "N/A"}</Text>
        </GridItem>
        <GridItem>
          <Text fontWeight="bold">Latitude:</Text>
          <Text>{consumer.latitude}</Text>
        </GridItem>
        <GridItem>
          <Text fontWeight="bold">Longitude:</Text>
          <Text>{consumer.longitude}</Text>
        </GridItem>
        <GridItem colSpan={2}>
          <Text fontWeight="bold">Created By:</Text>
          <Text>
            {consumer.created_by.first_name} {consumer.created_by.last_name || ""}
          </Text>
        </GridItem>
        <GridItem colSpan={2}>
          <Text fontWeight="bold">Created At:</Text>
          <Text>{moment(consumer.created_at).format("DD/MM/YYYY, hh:mm A")}</Text>
        </GridItem>
      </Grid>

      <VStack align="start" mt="6">
        <Heading as="h3" size="md" mb="2">
          Attachments
        </Heading>
        {consumer.attachments.length > 0 ? (
          <Flex gap="4" wrap="wrap">
            {consumer.attachments.map((attachment) => (
              <Box key={attachment.id} borderWidth="1px" borderRadius="md" p="2">
                <ImageWithFallback attachment={attachment} />
                <Text mt="2" fontSize="sm">
                  {attachment.file.filename}
                </Text>
              </Box>
            ))}
          </Flex>
        ) : (
          <Text>No attachments available.</Text>
        )}
      </VStack>
    </Box>
  );
};

export default ConsumerView;
